aboutsummaryrefslogtreecommitdiffstats
path: root/src/gdisp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gdisp')
-rw-r--r--src/gdisp/gdisp.c66
-rw-r--r--src/gdisp/gdisp.h88
-rw-r--r--src/gdisp/gdisp_colors.h79
-rw-r--r--src/gdisp/gdisp_driver.h120
-rw-r--r--src/gdisp/gdisp_image.h4
-rw-r--r--src/gdisp/gdisp_options.h252
-rw-r--r--src/gdisp/gdisp_pixmap.c10
-rw-r--r--src/gdisp/gdisp_pixmap.h4
-rw-r--r--src/gdisp/gdisp_rules.h20
9 files changed, 334 insertions, 309 deletions
diff --git a/src/gdisp/gdisp.c b/src/gdisp/gdisp.c
index c2439a16..ad5386fc 100644
--- a/src/gdisp/gdisp.c
+++ b/src/gdisp/gdisp.c
@@ -42,7 +42,7 @@ GDisplay *GDISP;
#define MUTEX_DEINIT(g)
#endif
-#define NEED_CLIPPING (GDISP_HARDWARE_CLIP != TRUE && (GDISP_NEED_VALIDATION || GDISP_NEED_CLIP))
+#define NEED_CLIPPING (GDISP_HARDWARE_CLIP != GFXON && (GDISP_NEED_VALIDATION || GDISP_NEED_CLIP))
#if !NEED_CLIPPING
#define TEST_CLIP_AREA(g)
@@ -119,7 +119,7 @@ static GFXINLINE void drawpixel(GDisplay *g) {
#endif
// Next best is cursor based streaming
- #if GDISP_HARDWARE_DRAWPIXEL != TRUE && GDISP_HARDWARE_STREAM_POS && GDISP_HARDWARE_STREAM_WRITE
+ #if GDISP_HARDWARE_DRAWPIXEL != GFXON && GDISP_HARDWARE_STREAM_POS && GDISP_HARDWARE_STREAM_WRITE
#if GDISP_HARDWARE_STREAM_POS == HARDWARE_AUTODETECT
if (gvmt(g)->writepos)
#endif
@@ -133,7 +133,7 @@ static GFXINLINE void drawpixel(GDisplay *g) {
#endif
// Worst is general streaming
- #if GDISP_HARDWARE_DRAWPIXEL != TRUE && GDISP_HARDWARE_STREAM_POS != TRUE && GDISP_HARDWARE_STREAM_WRITE
+ #if GDISP_HARDWARE_DRAWPIXEL != GFXON && GDISP_HARDWARE_STREAM_POS != GFXON && GDISP_HARDWARE_STREAM_WRITE
// The following test is unneeded because we are guaranteed to have streaming if we don't have drawpixel
//#if GDISP_HARDWARE_STREAM_WRITE == HARDWARE_AUTODETECT
// if (gvmt(g)->writestart)
@@ -191,7 +191,7 @@ static GFXINLINE void fillarea(GDisplay *g) {
#endif
// Next best is hardware streaming
- #if GDISP_HARDWARE_FILLS != TRUE && GDISP_HARDWARE_STREAM_WRITE
+ #if GDISP_HARDWARE_FILLS != GFXON && GDISP_HARDWARE_STREAM_WRITE
#if GDISP_HARDWARE_STREAM_WRITE == HARDWARE_AUTODETECT
if (gvmt(g)->writestart)
#endif
@@ -221,7 +221,7 @@ static GFXINLINE void fillarea(GDisplay *g) {
#endif
// Worst is pixel drawing
- #if GDISP_HARDWARE_FILLS != TRUE && GDISP_HARDWARE_STREAM_WRITE != TRUE && GDISP_HARDWARE_DRAWPIXEL
+ #if GDISP_HARDWARE_FILLS != GFXON && GDISP_HARDWARE_STREAM_WRITE != GFXON && GDISP_HARDWARE_DRAWPIXEL
// The following test is unneeded because we are guaranteed to have draw pixel if we don't have streaming
//#if GDISP_HARDWARE_DRAWPIXEL == HARDWARE_AUTODETECT
// if (gvmt(g)->pixel)
@@ -289,7 +289,7 @@ static void hline_clip(GDisplay *g) {
#endif
// Next best is cursor based streaming
- #if GDISP_HARDWARE_FILLS != TRUE && GDISP_HARDWARE_STREAM_POS && GDISP_HARDWARE_STREAM_WRITE
+ #if GDISP_HARDWARE_FILLS != GFXON && GDISP_HARDWARE_STREAM_POS && GDISP_HARDWARE_STREAM_WRITE
#if GDISP_HARDWARE_STREAM_POS == HARDWARE_AUTODETECT
if (gvmt(g)->writepos)
#endif
@@ -304,7 +304,7 @@ static void hline_clip(GDisplay *g) {
#endif
// Next best is streaming
- #if GDISP_HARDWARE_FILLS != TRUE && GDISP_HARDWARE_STREAM_POS != TRUE && GDISP_HARDWARE_STREAM_WRITE
+ #if GDISP_HARDWARE_FILLS != GFXON && GDISP_HARDWARE_STREAM_POS != GFXON && GDISP_HARDWARE_STREAM_WRITE
#if GDISP_HARDWARE_STREAM_WRITE == HARDWARE_AUTODETECT
if (gvmt(g)->writestart)
#endif
@@ -319,7 +319,7 @@ static void hline_clip(GDisplay *g) {
#endif
// Worst is drawing pixels
- #if GDISP_HARDWARE_FILLS != TRUE && GDISP_HARDWARE_STREAM_WRITE != TRUE && GDISP_HARDWARE_DRAWPIXEL
+ #if GDISP_HARDWARE_FILLS != GFXON && GDISP_HARDWARE_STREAM_WRITE != GFXON && GDISP_HARDWARE_DRAWPIXEL
// The following test is unneeded because we are guaranteed to have draw pixel if we don't have streaming
//#if GDISP_HARDWARE_DRAWPIXEL == HARDWARE_AUTODETECT
// if (gvmt(g)->pixel)
@@ -383,7 +383,7 @@ static void vline_clip(GDisplay *g) {
#endif
// Next best is streaming
- #if GDISP_HARDWARE_FILLS != TRUE && GDISP_HARDWARE_STREAM_WRITE
+ #if GDISP_HARDWARE_FILLS != GFXON && GDISP_HARDWARE_STREAM_WRITE
#if GDISP_HARDWARE_STREAM_WRITE == HARDWARE_AUTODETECT
if (gvmt(g)->writestart)
#endif
@@ -410,7 +410,7 @@ static void vline_clip(GDisplay *g) {
#endif
// Worst is drawing pixels
- #if GDISP_HARDWARE_FILLS != TRUE && GDISP_HARDWARE_STREAM_WRITE != TRUE && GDISP_HARDWARE_DRAWPIXEL
+ #if GDISP_HARDWARE_FILLS != GFXON && GDISP_HARDWARE_STREAM_WRITE != GFXON && GDISP_HARDWARE_DRAWPIXEL
// The following test is unneeded because we are guaranteed to have draw pixel if we don't have streaming
//#if GDISP_HARDWARE_DRAWPIXEL == HARDWARE_AUTODETECT
// if (gvmt(g)->pixel)
@@ -770,7 +770,7 @@ void gdispGFlush(GDisplay *g) {
#endif
// Worst - save the parameters and use pixel drawing and/or area fills
- #if GDISP_HARDWARE_STREAM_WRITE != TRUE && GDISP_HARDWARE_DRAWPIXEL
+ #if GDISP_HARDWARE_STREAM_WRITE != GFXON && GDISP_HARDWARE_DRAWPIXEL
// The following test is unneeded because we are guaranteed to have draw pixel if we don't have streaming
//#if GDISP_HARDWARE_DRAWPIXEL == HARDWARE_AUTODETECT
// if (gvmt(g)->pixel)
@@ -816,7 +816,7 @@ void gdispGFlush(GDisplay *g) {
#endif
// Next best is to use bitfills with our line buffer
- #if GDISP_HARDWARE_STREAM_WRITE != TRUE && GDISP_LINEBUF_SIZE != 0 && GDISP_HARDWARE_BITFILLS
+ #if GDISP_HARDWARE_STREAM_WRITE != GFXON && GDISP_LINEBUF_SIZE != 0 && GDISP_HARDWARE_BITFILLS
#if GDISP_HARDWARE_BITFILLS == HARDWARE_AUTODETECT
if (gvmt(g)->blit)
#endif
@@ -856,7 +856,7 @@ void gdispGFlush(GDisplay *g) {
#endif
// Only slightly better than drawing pixels is to look for runs and use fillarea
- #if GDISP_HARDWARE_STREAM_WRITE != TRUE && (GDISP_LINEBUF_SIZE == 0 || GDISP_HARDWARE_BITFILLS != TRUE) && GDISP_HARDWARE_FILLS
+ #if GDISP_HARDWARE_STREAM_WRITE != GFXON && (GDISP_LINEBUF_SIZE == 0 || GDISP_HARDWARE_BITFILLS != GFXON) && GDISP_HARDWARE_FILLS
// We don't need to test for auto-detect on drawpixel as we know we have it because we don't have streaming.
#if GDISP_HARDWARE_FILLS == HARDWARE_AUTODETECT
if (gvmt(g)->fill)
@@ -892,7 +892,7 @@ void gdispGFlush(GDisplay *g) {
#endif
// Worst is using pixel drawing
- #if GDISP_HARDWARE_STREAM_WRITE != TRUE && (GDISP_LINEBUF_SIZE == 0 || GDISP_HARDWARE_BITFILLS != TRUE) && GDISP_HARDWARE_FILLS != TRUE && GDISP_HARDWARE_DRAWPIXEL
+ #if GDISP_HARDWARE_STREAM_WRITE != GFXON && (GDISP_LINEBUF_SIZE == 0 || GDISP_HARDWARE_BITFILLS != GFXON) && GDISP_HARDWARE_FILLS != GFXON && GDISP_HARDWARE_DRAWPIXEL
// The following test is unneeded because we are guaranteed to have draw pixel if we don't have streaming
//#if GDISP_HARDWARE_DRAWPIXEL == HARDWARE_AUTODETECT
// if (gvmt(g)->pixel)
@@ -934,7 +934,7 @@ void gdispGFlush(GDisplay *g) {
}
#endif
- #if GDISP_HARDWARE_STREAM_WRITE != TRUE && GDISP_LINEBUF_SIZE != 0 && GDISP_HARDWARE_BITFILLS
+ #if GDISP_HARDWARE_STREAM_WRITE != GFXON && GDISP_LINEBUF_SIZE != 0 && GDISP_HARDWARE_BITFILLS
#if GDISP_HARDWARE_BITFILLS == HARDWARE_AUTODETECT
if (gvmt(g)->blit)
#endif
@@ -951,7 +951,7 @@ void gdispGFlush(GDisplay *g) {
}
#endif
- #if GDISP_HARDWARE_STREAM_WRITE != TRUE && (GDISP_LINEBUF_SIZE == 0 || GDISP_HARDWARE_BITFILLS != TRUE) && GDISP_HARDWARE_FILLS
+ #if GDISP_HARDWARE_STREAM_WRITE != GFXON && (GDISP_LINEBUF_SIZE == 0 || GDISP_HARDWARE_BITFILLS != GFXON) && GDISP_HARDWARE_FILLS
// We don't need to test for auto-detect on drawpixel as we know we have it because we don't have streaming.
#if GDISP_HARDWARE_FILLS == HARDWARE_AUTODETECT
if (gvmt(g)->fill)
@@ -969,7 +969,7 @@ void gdispGFlush(GDisplay *g) {
}
#endif
- #if GDISP_HARDWARE_STREAM_WRITE != TRUE && (GDISP_LINEBUF_SIZE == 0 || GDISP_HARDWARE_BITFILLS != TRUE) && GDISP_HARDWARE_FILLS != TRUE
+ #if GDISP_HARDWARE_STREAM_WRITE != GFXON && (GDISP_LINEBUF_SIZE == 0 || GDISP_HARDWARE_BITFILLS != GFXON) && GDISP_HARDWARE_FILLS != GFXON
{
autoflush_stopdone(g);
MUTEX_EXIT(g);
@@ -1019,7 +1019,7 @@ void gdispGClear(GDisplay *g, color_t color) {
#endif
// Next best is hardware accelerated area fill
- #if GDISP_HARDWARE_CLEARS != TRUE && GDISP_HARDWARE_FILLS
+ #if GDISP_HARDWARE_CLEARS != GFXON && GDISP_HARDWARE_FILLS
#if GDISP_HARDWARE_FILLS == HARDWARE_AUTODETECT
if (gvmt(g)->fill)
#endif
@@ -1036,7 +1036,7 @@ void gdispGClear(GDisplay *g, color_t color) {
#endif
// Next best is streaming
- #if GDISP_HARDWARE_CLEARS != TRUE && GDISP_HARDWARE_FILLS != TRUE && GDISP_HARDWARE_STREAM_WRITE
+ #if GDISP_HARDWARE_CLEARS != GFXON && GDISP_HARDWARE_FILLS != GFXON && GDISP_HARDWARE_STREAM_WRITE
#if GDISP_HARDWARE_STREAM_WRITE == HARDWARE_AUTODETECT
if (gvmt(g)->writestart)
#endif
@@ -1066,7 +1066,7 @@ void gdispGClear(GDisplay *g, color_t color) {
#endif
// Worst is drawing pixels
- #if GDISP_HARDWARE_CLEARS != TRUE && GDISP_HARDWARE_FILLS != TRUE && GDISP_HARDWARE_STREAM_WRITE != TRUE && GDISP_HARDWARE_DRAWPIXEL
+ #if GDISP_HARDWARE_CLEARS != GFXON && GDISP_HARDWARE_FILLS != GFXON && GDISP_HARDWARE_STREAM_WRITE != GFXON && GDISP_HARDWARE_DRAWPIXEL
// The following test is unneeded because we are guaranteed to have draw pixel if we don't have streaming
//#if GDISP_HARDWARE_DRAWPIXEL == HARDWARE_AUTODETECT
// if (gvmt(g)->pixel)
@@ -1137,7 +1137,7 @@ void gdispGBlitArea(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, c
#endif
// Next best is hardware streaming
- #if GDISP_HARDWARE_BITFILLS != TRUE && GDISP_HARDWARE_STREAM_WRITE
+ #if GDISP_HARDWARE_BITFILLS != GFXON && GDISP_HARDWARE_STREAM_WRITE
#if GDISP_HARDWARE_STREAM_WRITE == HARDWARE_AUTODETECT
if (gvmt(g)->writestart)
#endif
@@ -1173,7 +1173,7 @@ void gdispGBlitArea(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, c
#endif
// Only slightly better than drawing pixels is to look for runs and use fill area
- #if GDISP_HARDWARE_BITFILLS != TRUE && GDISP_HARDWARE_STREAM_WRITE != TRUE && GDISP_HARDWARE_FILLS
+ #if GDISP_HARDWARE_BITFILLS != GFXON && GDISP_HARDWARE_STREAM_WRITE != GFXON && GDISP_HARDWARE_FILLS
// We don't need to test for auto-detect on drawpixel as we know we have it because we don't have streaming.
#if GDISP_HARDWARE_FILLS == HARDWARE_AUTODETECT
if (gvmt(g)->fill)
@@ -1208,7 +1208,7 @@ void gdispGBlitArea(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, c
#endif
// Worst is drawing pixels
- #if GDISP_HARDWARE_BITFILLS != TRUE && GDISP_HARDWARE_STREAM_WRITE != TRUE && GDISP_HARDWARE_FILLS != TRUE && GDISP_HARDWARE_DRAWPIXEL
+ #if GDISP_HARDWARE_BITFILLS != GFXON && GDISP_HARDWARE_STREAM_WRITE != GFXON && GDISP_HARDWARE_FILLS != GFXON && GDISP_HARDWARE_DRAWPIXEL
// The following test is unneeded because we are guaranteed to have draw pixel if we don't have streaming
//#if GDISP_HARDWARE_DRAWPIXEL == HARDWARE_AUTODETECT
// if (gvmt(g)->pixel)
@@ -1255,7 +1255,7 @@ void gdispGBlitArea(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, c
#endif
// Worst is using software clipping
- #if GDISP_HARDWARE_CLIP != TRUE
+ #if GDISP_HARDWARE_CLIP != GFXON
{
if (x < 0) { cx += x; x = 0; }
if (y < 0) { cy += y; y = 0; }
@@ -2603,7 +2603,7 @@ void gdispGBlitArea(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, c
return c;
}
#endif
- #if GDISP_HARDWARE_PIXELREAD != TRUE && GDISP_HARDWARE_STREAM_READ
+ #if GDISP_HARDWARE_PIXELREAD != GFXON && GDISP_HARDWARE_STREAM_READ
#if GDISP_HARDWARE_STREAM_READ == HARDWARE_AUTODETECT
if (gvmt(g)->readcolor)
#endif
@@ -2620,7 +2620,7 @@ void gdispGBlitArea(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, c
return c;
}
#endif
- #if GDISP_HARDWARE_PIXELREAD != TRUE && GDISP_HARDWARE_STREAM_READ != TRUE
+ #if GDISP_HARDWARE_PIXELREAD != GFXON && GDISP_HARDWARE_STREAM_READ != GFXON
#if !GDISP_HARDWARE_PIXELREAD && !GDISP_HARDWARE_STREAM_READ
// Worst is "not possible"
#error "GDISP: GDISP_NEED_PIXELREAD has been set but there is no hardware support for reading the display"
@@ -2634,7 +2634,7 @@ void gdispGBlitArea(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, c
#if GDISP_NEED_SCROLL
void gdispGVerticalScroll(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, int lines, color_t bgcolor) {
coord_t abslines;
- #if GDISP_HARDWARE_SCROLL != TRUE
+ #if GDISP_HARDWARE_SCROLL != GFXON
coord_t fy, dy, ix, fx, i, j;
#endif
@@ -2682,7 +2682,7 @@ void gdispGBlitArea(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, c
#endif
// Scroll Emulation
- #if GDISP_HARDWARE_SCROLL != TRUE
+ #if GDISP_HARDWARE_SCROLL != GFXON
{
cy -= abslines;
if (lines < 0) {
@@ -2726,7 +2726,7 @@ void gdispGBlitArea(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, c
#endif
// Next best line read is single pixel reads
- #if GDISP_HARDWARE_STREAM_READ != TRUE && GDISP_HARDWARE_PIXELREAD
+ #if GDISP_HARDWARE_STREAM_READ != GFXON && GDISP_HARDWARE_PIXELREAD
#if GDISP_HARDWARE_PIXELREAD == HARDWARE_AUTODETECT
if (gvmt(g)->get)
#endif
@@ -2775,7 +2775,7 @@ void gdispGBlitArea(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, c
#endif
// Next best line write is hardware streaming
- #if GDISP_HARDWARE_BITFILLS != TRUE && GDISP_HARDWARE_STREAM_WRITE
+ #if GDISP_HARDWARE_BITFILLS != GFXON && GDISP_HARDWARE_STREAM_WRITE
#if GDISP_HARDWARE_STREAM_WRITE == HARDWARE_AUTODETECT
if (gvmt(g)->writestart)
#endif
@@ -2800,7 +2800,7 @@ void gdispGBlitArea(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, c
#endif
// Next best line write is drawing pixels in combination with filling
- #if GDISP_HARDWARE_BITFILLS != TRUE && GDISP_HARDWARE_STREAM_WRITE != TRUE && GDISP_HARDWARE_FILLS && GDISP_HARDWARE_DRAWPIXEL
+ #if GDISP_HARDWARE_BITFILLS != GFXON && GDISP_HARDWARE_STREAM_WRITE != GFXON && GDISP_HARDWARE_FILLS && GDISP_HARDWARE_DRAWPIXEL
// We don't need to test for auto-detect on drawpixel as we know we have it because we don't have streaming.
#if GDISP_HARDWARE_FILLS == HARDWARE_AUTODETECT
if (gvmt(g)->fill)
@@ -2832,7 +2832,7 @@ void gdispGBlitArea(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, c
#endif
// Worst line write is drawing pixels
- #if GDISP_HARDWARE_BITFILLS != TRUE && GDISP_HARDWARE_STREAM_WRITE != TRUE && GDISP_HARDWARE_FILLS != TRUE && GDISP_HARDWARE_DRAWPIXEL
+ #if GDISP_HARDWARE_BITFILLS != GFXON && GDISP_HARDWARE_STREAM_WRITE != GFXON && GDISP_HARDWARE_FILLS != GFXON && GDISP_HARDWARE_DRAWPIXEL
// The following test is unneeded because we are guaranteed to have draw pixel if we don't have streaming
//#if GDISP_HARDWARE_DRAWPIXEL == HARDWARE_AUTODETECT
// if (gvmt(g)->pixel)
@@ -2906,7 +2906,7 @@ void gdispGBlitArea(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, c
#endif
// Worst is software clipping
- #if GDISP_HARDWARE_CLIP != TRUE
+ #if GDISP_HARDWARE_CLIP != GFXON
{
g->clipx0 = 0;
g->clipy0 = 0;
diff --git a/src/gdisp/gdisp.h b/src/gdisp/gdisp.h
index 4a097604..5bf2b284 100644
--- a/src/gdisp/gdisp.h
+++ b/src/gdisp/gdisp.h
@@ -15,7 +15,7 @@
*
* @details The GDISP module provides high level abstraction to interface pixel oriented graphic displays.
*
- * @pre GFX_USE_GDISP must be set to TRUE in gfxconf.h
+ * @pre GFX_USE_GDISP must be set to GFXON in gfxconf.h
*
* @note Each drawing routine supports a gdispXXXX and a gdispGXXXX function. The difference is that the
* gdispXXXX function does not require a display to be specified. Note there is a slight anomaly
@@ -30,7 +30,7 @@
#include "../../gfx.h"
/* This type definition is defined here as it gets used in other gfx sub-systems even
- * if GFX_USE_GDISP is FALSE.
+ * if GFX_USE_GDISP is GFXOFF.
*/
/**
@@ -201,15 +201,15 @@ extern GDisplay *GDISP;
* @note Packed pixels are not really supported at this point.
*/
#ifndef GDISP_PACKED_PIXELS
- #define GDISP_PACKED_PIXELS FALSE
+ #define GDISP_PACKED_PIXELS GFXOFF
#endif
/**
* @brief Do lines of pixels require packing for a blit
- * @note Ignored if GDISP_PACKED_PIXELS is FALSE
+ * @note Ignored if GDISP_PACKED_PIXELS is GFXOFF
*/
#ifndef GDISP_PACKED_LINES
- #define GDISP_PACKED_LINES FALSE
+ #define GDISP_PACKED_LINES GFXOFF
#endif
/** @} */
@@ -377,7 +377,7 @@ uint8_t gdispGGetContrast(GDisplay *g);
* know your controller does not need to be flushed there is no
* need to call it (which is in reality most controllers).
* @note Even for displays that require flushing, there is no need to
- * call this function if GDISP_NEED_AUTOFLUSH is TRUE.
+ * call this function if GDISP_NEED_AUTOFLUSH is GFXON.
* Calling it again won't hurt though.
*
*
@@ -478,7 +478,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Start a streaming operation.
* @details Stream data to a window on the display sequentially and very fast.
- * @pre GDISP_NEED_STREAMING must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_STREAMING must be GFXON in your gfxconf.h
* @note While streaming is in operation - no other calls to GDISP functions
* can be made (with the exception of @p gdispBlendColor() and streaming
* functions). If a call is made (eg in a multi-threaded application) the other
@@ -505,7 +505,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Send pixel data to the stream.
* @details Write a pixel to the next position in the streamed area and increment the position
- * @pre GDISP_NEED_STREAMING must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_STREAMING must be GFXON in your gfxconf.h
* @pre @p gdispStreamStart() has been called.
* @note If the gdispStreamStart() has not been called (or failed due to clipping), the
* data provided here is simply thrown away.
@@ -521,7 +521,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Finish the current streaming operation.
* @details Completes the current streaming operation and allows other GDISP calls to operate again.
- * @pre GDISP_NEED_STREAMING must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_STREAMING must be GFXON in your gfxconf.h
* @pre @p gdispStreamStart() has been called.
* @note If the gdispStreamStart() has not been called (or failed due to clipping), this
* call is simply ignored.
@@ -539,7 +539,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
#if GDISP_NEED_CLIP || defined(__DOXYGEN__)
/**
* @brief Clip all drawing to the defined area.
- * @pre GDISP_NEED_CLIP must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_CLIP must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The start position
@@ -556,7 +556,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
#if GDISP_NEED_CIRCLE || defined(__DOXYGEN__)
/**
* @brief Draw a circle.
- * @pre GDISP_NEED_CIRCLE must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_CIRCLE must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The center of the circle
@@ -570,7 +570,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Draw a filled circle.
- * @pre GDISP_NEED_CIRCLE must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_CIRCLE must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The center of the circle
@@ -586,7 +586,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
#if GDISP_NEED_DUALCIRCLE || defined(__DOXYGEN__)
/**
* @brief Draw two filled circles with the same centre.
- * @pre GDISP_NEED_DUALCIRCLE must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_DUALCIRCLE must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The center of the circle
@@ -606,7 +606,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
#if GDISP_NEED_ELLIPSE || defined(__DOXYGEN__)
/**
* @brief Draw an ellipse.
- * @pre GDISP_NEED_ELLIPSE must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_ELLIPSE must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The center of the ellipse
@@ -620,7 +620,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Draw a filled ellipse.
- * @pre GDISP_NEED_ELLIPSE must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_ELLIPSE must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The center of the ellipse
@@ -637,7 +637,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
#if GDISP_NEED_ARCSECTORS || defined(__DOXYGEN__)
/**
* @brief Draw a selection of 45 degree arcs of a circle
- * @pre GDISP_NEED_ARCSECTORS must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_ARCSECTORS must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The center of the circle
@@ -666,7 +666,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Fill a selection of 45 degree arcs of a circle
- * @pre GDISP_NEED_ARCSECTORS must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_ARCSECTORS must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The center of the circle
@@ -697,7 +697,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
#if GDISP_NEED_ARC || defined(__DOXYGEN__)
/**
* @brief Draw an arc.
- * @pre GDISP_NEED_ARC must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_ARC must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The center point
@@ -722,7 +722,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Draw a thick arc.
- * @pre GDISP_NEED_ARC must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_ARC must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] xc,yc The center point
@@ -747,7 +747,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Draw a filled arc.
- * @pre GDISP_NEED_ARC must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_ARC must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The center point
@@ -777,7 +777,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Get the color of a pixel.
* @return The color of the pixel.
- * @pre GDISP_NEED_PIXELREAD must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_PIXELREAD must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The position of the pixel
@@ -793,7 +793,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
#if GDISP_NEED_SCROLL || defined(__DOXYGEN__)
/**
* @brief Scroll vertically a section of the screen.
- * @pre GDISP_NEED_SCROLL must be set to TRUE in gfxconf.h
+ * @pre GDISP_NEED_SCROLL must be set to GFXON in gfxconf.h
* @note Optional.
* @note If lines is >= cy, it is equivelent to an area fill with bgcolor.
*
@@ -814,7 +814,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
#if GDISP_NEED_CONTROL || defined(__DOXYGEN__)
/**
* @brief Control hardware specific parts of the display. eg powermodes, backlight etc
- * @pre GDISP_NEED_CONTROL must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_CONTROL must be GFXON in your gfxconf.h
* @note Depending on the hardware implementation this function may not
* support some codes. They will be ignored.
*
@@ -833,7 +833,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
#if GDISP_NEED_QUERY || defined(__DOXYGEN__)
/**
* @brief Query a property of the display.
- * @pre GDISP_NEED_QUERY must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_QUERY must be GFXON in your gfxconf.h
* @note The result must be typecast to the correct type.
* @note An unsupported query will return (void *)-1.
*
@@ -849,7 +849,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
#if GDISP_NEED_CONVEX_POLYGON || defined(__DOXYGEN__)
/**
* @brief Draw an enclosed polygon (convex, non-convex or complex).
- * @pre GDISP_NEED_CONVEX_POLYGON must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_CONVEX_POLYGON must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] tx, ty Transform all points in pntarray by tx, ty
@@ -865,7 +865,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Fill a convex polygon
* @details Doesn't handle non-convex or complex polygons.
- * @pre GDISP_NEED_CONVEX_POLYGON must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_CONVEX_POLYGON must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] tx, ty Transform all points in pntarray by tx, ty
@@ -890,7 +890,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
* @brief Draw a line with a specified thickness
* @details The line thickness is specified in pixels. The line ends can
* be selected to be either flat or round.
- * @pre GDISP_NEED_CONVEX_POLYGON must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_CONVEX_POLYGON must be GFXON in your gfxconf.h
* @note Uses gdispGFillConvexPoly() internally to perform the drawing.
*
* @param[in] g The display to use
@@ -911,7 +911,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
#if GDISP_NEED_TEXT || defined(__DOXYGEN__)
/**
* @brief Draw a text character.
- * @pre GDISP_NEED_TEXT must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The position for the text
@@ -926,7 +926,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Draw a text character with a filled background.
- * @pre GDISP_NEED_TEXT must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The position for the text
@@ -942,7 +942,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Draw a text string.
- * @pre GDISP_NEED_TEXT must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The position for the text
@@ -957,7 +957,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Draw a text string.
- * @pre GDISP_NEED_TEXT must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The position for the text
@@ -973,7 +973,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Draw a text string vertically centered within the specified box.
- * @pre GDISP_NEED_TEXT must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The position for the text (need to define top-right or base-line - check code)
@@ -990,7 +990,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Draw a text string vertically centered within the specified box. The box background is filled with the specified background color.
- * @pre GDISP_NEED_TEXT must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be GFXON in your gfxconf.h
* @note The entire box is filled
*
* @param[in] g The display to use
@@ -1010,7 +1010,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Get a metric of a font.
* @return The metric requested in pixels.
- * @pre GDISP_NEED_TEXT must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be GFXON in your gfxconf.h
*
* @param[in] font The font to test
* @param[in] metric The metric to measure
@@ -1022,7 +1022,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Get the pixel width of a character.
* @return The width of the character in pixels. Does not include any between character padding.
- * @pre GDISP_NEED_TEXT must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be GFXON in your gfxconf.h
*
* @param[in] c The character to draw
* @param[in] font The font to use
@@ -1034,7 +1034,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Get the pixel width of a string of a given character length.
* @return The width of the string in pixels.
- * @pre GDISP_NEED_TEXT must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be GFXON in your gfxconf.h
*
* @note Passing 0 to count has the same effect as calling gdispGetStringWidt()
*
@@ -1049,7 +1049,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Get the pixel width of an entire string.
* @return The width of the string in pixels.
- * @pre GDISP_NEED_TEXT must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be GFXON in your gfxconf.h
*
* @param[in] str The string to measure
* @param[in] font The font to use
@@ -1062,7 +1062,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
* @brief Find a font and return it.
* @details The supplied name is matched against the font name. A '*' will replace 0 or more characters.
* @return Returns a font or NULL if no matching font could be found.
- * @pre GDISP_NEED_TEXT must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be GFXON in your gfxconf.h
*
* @param[in] name The font name to find.
*
@@ -1074,7 +1074,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Release a font after use.
- * @pre GDISP_NEED_TEXT must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be GFXON in your gfxconf.h
*
* @param[in] font The font to release.
*
@@ -1086,7 +1086,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
* @brief Make a scaled copy of an existing font.
* @details Allocates memory for new font metadata using gfxAlloc, remember to close font after use!
* @return A new font or NULL if out of memory.
- * @pre GDISP_NEED_TEXT must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be GFXON in your gfxconf.h
* @note A scaled font should probably not be added to the font list as it will prevent the
* unscaled font of the same name being found as it will be the scaled version that will be found.
*
@@ -1099,7 +1099,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Get the name of the specified font.
* @returns The name of the font.
- * @pre GDISP_NEED_TEXT must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be GFXON in your gfxconf.h
*
* @param[in] font The font to get the name for.
*
@@ -1110,7 +1110,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Add a font permanently to the font list.
* @returns TRUE on success. Reasons it may fail: out of memory, if it is already on the list, it is not a font loaded in RAM.
- * @pre GDISP_NEED_TEXT must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_TEXT must be GFXON in your gfxconf.h
*
* @param[in] font The font to add to the font list.
*
@@ -1124,7 +1124,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
#if GDISP_NEED_ARC || GDISP_NEED_ARCSECTORS || defined(__DOXYGEN__)
/**
* @brief Draw a rectangular box with rounded corners
- * @pre GDISP_NEED_ARC or GDISP_NEED_ARCSECTORS must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_ARC or GDISP_NEED_ARCSECTORS must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The start position
@@ -1139,7 +1139,7 @@ void gdispGDrawBox(GDisplay *g, coord_t x, coord_t y, coord_t cx, coord_t cy, co
/**
* @brief Draw a filled rectangular box with rounded corners
- * @pre GDISP_NEED_ARC or GDISP_NEED_ARCSECTORS must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_ARC or GDISP_NEED_ARCSECTORS must be GFXON in your gfxconf.h
*
* @param[in] g The display to use
* @param[in] x,y The start position
diff --git a/src/gdisp/gdisp_colors.h b/src/gdisp/gdisp_colors.h
index 0973e561..bf1a3f3b 100644
--- a/src/gdisp/gdisp_colors.h
+++ b/src/gdisp/gdisp_colors.h
@@ -80,30 +80,55 @@ typedef uint16_t colorformat;
* @name Some basic colors
* @{
*/
-#define White HTML2COLOR(0xFFFFFF)
-#define Black HTML2COLOR(0x000000)
-#define Gray HTML2COLOR(0x808080)
-#define Grey Gray
-#define Blue HTML2COLOR(0x0000FF)
-#define Red HTML2COLOR(0xFF0000)
-#define Fuchsia HTML2COLOR(0xFF00FF)
-#define Magenta Fuchsia
-#define Green HTML2COLOR(0x008000)
-#define Yellow HTML2COLOR(0xFFFF00)
-#define Aqua HTML2COLOR(0x00FFFF)
-#define Cyan Aqua
-#define Lime HTML2COLOR(0x00FF00)
-#define Maroon HTML2COLOR(0x800000)
-#define Navy HTML2COLOR(0x000080)
-#define Olive HTML2COLOR(0x808000)
-#define Purple HTML2COLOR(0x800080)
-#define Silver HTML2COLOR(0xC0C0C0)
-#define Teal HTML2COLOR(0x008080)
-#define Orange HTML2COLOR(0xFFA500)
-#define Pink HTML2COLOR(0xFFC0CB)
-#define SkyBlue HTML2COLOR(0x87CEEB)
+#define GFXWHITE HTML2COLOR(0xFFFFFF)
+#define GFXBLACK HTML2COLOR(0x000000)
+#define GFXGRAY HTML2COLOR(0x808080)
+#define GFXGREY GFXGRAY
+#define GFXBLUE HTML2COLOR(0x0000FF)
+#define GFXRED HTML2COLOR(0xFF0000)
+#define GFXFUCHSIA HTML2COLOR(0xFF00FF)
+#define GFXMAGENTA GFXFUCHSIA
+#define GFXGREEN HTML2COLOR(0x008000)
+#define GFXYELLOW HTML2COLOR(0xFFFF00)
+#define GFXAQUA HTML2COLOR(0x00FFFF)
+#define GFXCYAN GFXAQUA
+#define GFXLIME HTML2COLOR(0x00FF00)
+#define GFXMAROON HTML2COLOR(0x800000)
+#define GFXNAVY HTML2COLOR(0x000080)
+#define GFXOLIVE HTML2COLOR(0x808000)
+#define GFXPURPLE HTML2COLOR(0x800080)
+#define GFXSILVER HTML2COLOR(0xC0C0C0)
+#define GFXTEAL HTML2COLOR(0x008080)
+#define GFXORANGE HTML2COLOR(0xFFA500)
+#define GFXPINK HTML2COLOR(0xFFC0CB)
+#define GFXSKYBLUE HTML2COLOR(0x87CEEB)
/** @} */
+#if GFX_COMPAT_V2 && GFX_COMPAT_OLDCOLORS
+ #define White GFXWHITE
+ #define Black GFXBLACK
+ #define Gray GFXGRAY
+ #define Grey GFXGREY
+ #define Blue GFXBLUE
+ #define Red GFXRED
+ #define Fuchsia GFXFUCHSIA
+ #define Magenta GFXMAGENTA
+ #define Green GFXGREEN
+ #define Yellow GFXYELLOW
+ #define Aqua GFXAQUA
+ #define Cyan GFXCYAN
+ #define Lime GFXLIME
+ #define Maroon GFXMAROON
+ #define Navy GFXNAVY
+ #define Olive GFXOLIVE
+ #define Purple GFXPURPLE
+ #define Silver GFXSILVER
+ #define Teal GFXTEAL
+ #define Orange GFXORANGE
+ #define Pink GFXPINK
+ #define SkyBlue GFXSKYBLUE
+#endif
+
#if defined(__DOXYGEN__)
/**
* @brief The color system (grayscale, palette or truecolor)
@@ -138,7 +163,7 @@ typedef uint16_t colorformat;
/**
* @brief Does the color need masking to remove invalid bits
*/
- #define COLOR_NEEDS_MASK FALSE
+ #define COLOR_NEEDS_MASK GFXOFF
/**
* @brief If the color needs masking to remove invalid bits, this is the mask
@@ -248,9 +273,9 @@ typedef uint16_t colorformat;
#error "GDISP: Cannot define color types with more than 32 bits"
#endif
#if COLOR_TYPE_BITS == COLOR_BITS
- #define COLOR_NEEDS_MASK FALSE
+ #define COLOR_NEEDS_MASK GFXOFF
#else
- #define COLOR_NEEDS_MASK TRUE
+ #define COLOR_NEEDS_MASK GFXON
#endif
#define COLOR_MASK() ((1 << COLOR_BITS)-1)
@@ -363,9 +388,9 @@ typedef uint16_t colorformat;
#error "GDISP: Cannot define gray-scale color types with more than 8 bits"
#endif
#if COLOR_TYPE_BITS == COLOR_BITS
- #define COLOR_NEEDS_MASK FALSE
+ #define COLOR_NEEDS_MASK GFXOFF
#else
- #define COLOR_NEEDS_MASK TRUE
+ #define COLOR_NEEDS_MASK GFXON
#endif
#define COLOR_MASK() ((1 << COLOR_BITS)-1)
diff --git a/src/gdisp/gdisp_driver.h b/src/gdisp/gdisp_driver.h
index 09a12b06..14e019ff 100644
--- a/src/gdisp/gdisp_driver.h
+++ b/src/gdisp/gdisp_driver.h
@@ -23,28 +23,28 @@
// Are we currently compiling the driver itself?
#if defined(GDISP_DRIVER_VMT)
- #define IN_DRIVER TRUE
+ #define IN_DRIVER GFXON
#else
- #define IN_DRIVER FALSE
+ #define IN_DRIVER GFXOFF
#endif
// Is this a multiple driver situation?
#if defined(GDISP_DRIVER_LIST)
- #define IS_MULTIPLE TRUE
+ #define IS_MULTIPLE GFXON
#else
- #define IS_MULTIPLE FALSE
+ #define IS_MULTIPLE GFXOFF
#endif
// Do we need to use VMT calling rather than direct calls to the driver?
#if IS_MULTIPLE || GDISP_NEED_PIXMAP
- #define USE_VMT TRUE
+ #define USE_VMT GFXON
#else
- #define USE_VMT FALSE
+ #define USE_VMT GFXOFF
#endif
// Are we in the pixmap virtual driver
#ifndef IN_PIXMAP_DRIVER
- #define IN_PIXMAP_DRIVER FALSE
+ #define IN_PIXMAP_DRIVER GFXOFF
#endif
//------------------------------------------------------------------------------------------------------------
@@ -57,7 +57,7 @@
#define HARDWARE_DEFAULT HARDWARE_AUTODETECT
#else
// The default is not to include code functions that aren't needed
- #define HARDWARE_DEFAULT FALSE
+ #define HARDWARE_DEFAULT GFXOFF
#endif
//------------------------------------------------------------------------------------------------------------
@@ -68,7 +68,7 @@
*/
/**
* @brief The display hardware can benefit from being de-initialized when usage is complete.
- * @details Can be set to TRUE, FALSE or HARDWARE_AUTODETECT
+ * @details Can be set to GFXON, GFXOFF or HARDWARE_AUTODETECT
*
* @note HARDWARE_AUTODETECT is only meaningful when GDISP_DRIVER_LIST is defined
* @note This is most useful for displays such as remote network displays.
@@ -79,7 +79,7 @@
/**
* @brief The display hardware can benefit from being flushed.
- * @details Can be set to TRUE, FALSE or HARDWARE_AUTODETECT
+ * @details Can be set to GFXON, GFXOFF or HARDWARE_AUTODETECT
*
* @note HARDWARE_AUTODETECT is only meaningful when GDISP_DRIVER_LIST is defined
* @note Some controllers ** require ** the application to flush
@@ -90,7 +90,7 @@
/**
* @brief Hardware streaming writing is supported.
- * @details Can be set to TRUE, FALSE or HARDWARE_AUTODETECT
+ * @details Can be set to GFXON, GFXOFF or HARDWARE_AUTODETECT
*
* @note HARDWARE_AUTODETECT is only meaningful when GDISP_DRIVER_LIST is defined
* @note Either GDISP_HARDWARE_STREAM_WRITE or GDISP_HARDWARE_DRAWPIXEL must be provided by each driver
@@ -101,7 +101,7 @@
/**
* @brief Hardware streaming reading of the display surface is supported.
- * @details Can be set to TRUE, FALSE or HARDWARE_AUTODETECT
+ * @details Can be set to GFXON, GFXOFF or HARDWARE_AUTODETECT
*
* @note HARDWARE_AUTODETECT is only meaningful when GDISP_DRIVER_LIST is defined
*
@@ -112,7 +112,7 @@
/**
* @brief Hardware supports setting the cursor position within the stream window.
- * @details Can be set to TRUE, FALSE or HARDWARE_AUTODETECT
+ * @details Can be set to GFXON, GFXOFF or HARDWARE_AUTODETECT
*
* @note HARDWARE_AUTODETECT is only meaningful when GDISP_DRIVER_LIST is defined
* @note This is used to optimise setting of individual pixels within a stream window.
@@ -125,7 +125,7 @@
/**
* @brief Hardware accelerated draw pixel.
- * @details Can be set to TRUE, FALSE or HARDWARE_AUTODETECT
+ * @details Can be set to GFXON, GFXOFF or HARDWARE_AUTODETECT
*
* @note HARDWARE_AUTODETECT is only meaningful when GDISP_DRIVER_LIST is defined
* @note Either GDISP_HARDWARE_STREAM_WRITE or GDISP_HARDWARE_DRAWPIXEL must be provided by the driver
@@ -136,7 +136,7 @@
/**
* @brief Hardware accelerated screen clears.
- * @details Can be set to TRUE, FALSE or HARDWARE_AUTODETECT
+ * @details Can be set to GFXON, GFXOFF or HARDWARE_AUTODETECT
*
* @note HARDWARE_AUTODETECT is only meaningful when GDISP_DRIVER_LIST is defined
* @note This clears the entire display surface regardless of the clipping area currently set
@@ -147,7 +147,7 @@
/**
* @brief Hardware accelerated rectangular fills.
- * @details Can be set to TRUE, FALSE or HARDWARE_AUTODETECT
+ * @details Can be set to GFXON, GFXOFF or HARDWARE_AUTODETECT
*
* @note HARDWARE_AUTODETECT is only meaningful when GDISP_DRIVER_LIST is defined
*/
@@ -157,7 +157,7 @@
/**
* @brief Hardware accelerated fills from an image.
- * @details Can be set to TRUE, FALSE or HARDWARE_AUTODETECT
+ * @details Can be set to GFXON, GFXOFF or HARDWARE_AUTODETECT
*
* @note HARDWARE_AUTODETECT is only meaningful when GDISP_DRIVER_LIST is defined
*/
@@ -167,7 +167,7 @@
/**
* @brief Hardware accelerated scrolling.
- * @details Can be set to TRUE, FALSE or HARDWARE_AUTODETECT
+ * @details Can be set to GFXON, GFXOFF or HARDWARE_AUTODETECT
*
* @note HARDWARE_AUTODETECT is only meaningful when GDISP_DRIVER_LIST is defined
*/
@@ -177,7 +177,7 @@
/**
* @brief Reading back of pixel values.
- * @details Can be set to TRUE, FALSE or HARDWARE_AUTODETECT
+ * @details Can be set to GFXON, GFXOFF or HARDWARE_AUTODETECT
*
* @note HARDWARE_AUTODETECT is only meaningful when GDISP_DRIVER_LIST is defined
*/
@@ -187,7 +187,7 @@
/**
* @brief The driver supports one or more control commands.
- * @details Can be set to TRUE, FALSE or HARDWARE_AUTODETECT
+ * @details Can be set to GFXON, GFXOFF or HARDWARE_AUTODETECT
*
* @note HARDWARE_AUTODETECT is only meaningful when GDISP_DRIVER_LIST is defined
*/
@@ -197,7 +197,7 @@
/**
* @brief The driver supports a non-standard query.
- * @details Can be set to TRUE, FALSE or HARDWARE_AUTODETECT
+ * @details Can be set to GFXON, GFXOFF or HARDWARE_AUTODETECT
*
* @note HARDWARE_AUTODETECT is only meaningful when GDISP_DRIVER_LIST is defined
*/
@@ -207,7 +207,7 @@
/**
* @brief The driver supports a clipping in hardware.
- * @details Can be set to TRUE, FALSE or HARDWARE_AUTODETECT
+ * @details Can be set to GFXON, GFXOFF or HARDWARE_AUTODETECT
*
* @note HARDWARE_AUTODETECT is only meaningful when GDISP_DRIVER_LIST is defined
* @note If this is defined the driver must perform its own clipping on all calls to
@@ -223,8 +223,8 @@
//------------------------------------------------------------------------------------------------------------
-// For pixmaps certain routines MUST not be FALSE as they are needed for pixmap drawing
-// Similarly some routines MUST not be TRUE as pixmap's don't provide them.
+// For pixmaps certain routines MUST not be GFXOFF as they are needed for pixmap drawing
+// Similarly some routines MUST not be GFXON as pixmap's don't provide them.
#if GDISP_NEED_PIXMAP && !IN_DRIVER
#if !GDISP_HARDWARE_DEINIT
#undef GDISP_HARDWARE_DEINIT
@@ -242,39 +242,39 @@
#undef GDISP_HARDWARE_CONTROL
#define GDISP_HARDWARE_CONTROL HARDWARE_AUTODETECT
#endif
- #if GDISP_HARDWARE_FLUSH == TRUE
+ #if GDISP_HARDWARE_FLUSH == GFXON
#undef GDISP_HARDWARE_FLUSH
#define GDISP_HARDWARE_FLUSH HARDWARE_AUTODETECT
#endif
- #if GDISP_HARDWARE_STREAM_WRITE == TRUE
+ #if GDISP_HARDWARE_STREAM_WRITE == GFXON
#undef GDISP_HARDWARE_STREAM_WRITE
#define GDISP_HARDWARE_STREAM_WRITE HARDWARE_AUTODETECT
#endif
- #if GDISP_HARDWARE_STREAM_READ == TRUE
+ #if GDISP_HARDWARE_STREAM_READ == GFXON
#undef GDISP_HARDWARE_STREAM_READ
#define GDISP_HARDWARE_STREAM_READ HARDWARE_AUTODETECT
#endif
- #if GDISP_HARDWARE_CLEARS == TRUE
+ #if GDISP_HARDWARE_CLEARS == GFXON
#undef GDISP_HARDWARE_CLEARS
#define GDISP_HARDWARE_CLEARS HARDWARE_AUTODETECT
#endif
- #if GDISP_HARDWARE_FILLS == TRUE
+ #if GDISP_HARDWARE_FILLS == GFXON
#undef GDISP_HARDWARE_FILLS
#define GDISP_HARDWARE_FILLS HARDWARE_AUTODETECT
#endif
- #if GDISP_HARDWARE_BITFILLS == TRUE
+ #if GDISP_HARDWARE_BITFILLS == GFXON
#undef GDISP_HARDWARE_BITFILLS
#define GDISP_HARDWARE_BITFILLS HARDWARE_AUTODETECT
#endif
- #if GDISP_HARDWARE_SCROLL == TRUE
+ #if GDISP_HARDWARE_SCROLL == GFXON
#undef GDISP_HARDWARE_SCROLL
#define GDISP_HARDWARE_SCROLL HARDWARE_AUTODETECT
#endif
- #if GDISP_HARDWARE_QUERY == TRUE
+ #if GDISP_HARDWARE_QUERY == GFXON
#undef GDISP_HARDWARE_QUERY
#define GDISP_HARDWARE_QUERY HARDWARE_AUTODETECT
#endif
- #if GDISP_HARDWARE_CLIP == TRUE
+ #if GDISP_HARDWARE_CLIP == GFXON
#undef GDISP_HARDWARE_CLIP
#define GDISP_HARDWARE_CLIP HARDWARE_AUTODETECT
#endif
@@ -342,7 +342,7 @@ struct GDisplay {
#endif
// Software clipping
- #if GDISP_HARDWARE_CLIP != TRUE && (GDISP_NEED_CLIP || GDISP_NEED_VALIDATION)
+ #if GDISP_HARDWARE_CLIP != GFXON && (GDISP_NEED_CLIP || GDISP_NEED_VALIDATION)
coord_t clipx0, clipy0;
coord_t clipx1, clipy1; /* not inclusive */
#endif
@@ -430,7 +430,7 @@ typedef struct GDISPVMT {
#if GDISP_HARDWARE_DEINIT || defined(__DOXYGEN__)
/**
* @brief The driver is being de-initialized
- * @pre GDISP_HARDWARE_FLUSH is TRUE
+ * @pre GDISP_HARDWARE_FLUSH is GFXON
*
* @param[in] g The driver structure
*
@@ -441,7 +441,7 @@ typedef struct GDISPVMT {
#if GDISP_HARDWARE_FLUSH || defined(__DOXYGEN__)
/**
* @brief Flush the current drawing operations to the display
- * @pre GDISP_HARDWARE_FLUSH is TRUE
+ * @pre GDISP_HARDWARE_FLUSH is GFXON
*
* @param[in] g The driver structure
*
@@ -453,7 +453,7 @@ typedef struct GDISPVMT {
#if GDISP_HARDWARE_STREAM_WRITE || defined(__DOXYGEN__)
/**
* @brief Start a streamed write operation
- * @pre GDISP_HARDWARE_STREAM_WRITE is TRUE
+ * @pre GDISP_HARDWARE_STREAM_WRITE is GFXON
*
* @param[in] g The driver structure
*
@@ -463,13 +463,13 @@ typedef struct GDISPVMT {
* @note The parameter variables must not be altered by the driver.
* @note Streaming operations that wrap the defined window have
* undefined results.
- * @note This must be followed by a call to @p gdisp_lld_write_pos() if GDISP_HARDWARE_STREAM_POS is TRUE.
+ * @note This must be followed by a call to @p gdisp_lld_write_pos() if GDISP_HARDWARE_STREAM_POS is GFXON.
*/
LLDSPEC void gdisp_lld_write_start(GDisplay *g);
/**
* @brief Send a pixel to the current streaming position and then increment that position
- * @pre GDISP_HARDWARE_STREAM_WRITE is TRUE
+ * @pre GDISP_HARDWARE_STREAM_WRITE is GFXON
*
* @param[in] g The driver structure
*
@@ -480,7 +480,7 @@ typedef struct GDISPVMT {
/**
* @brief End the current streaming write operation
- * @pre GDISP_HARDWARE_STREAM_WRITE is TRUE
+ * @pre GDISP_HARDWARE_STREAM_WRITE is GFXON
*
* @param[in] g The driver structure
*
@@ -491,7 +491,7 @@ typedef struct GDISPVMT {
#if GDISP_HARDWARE_STREAM_POS || defined(__DOXYGEN__)
/**
* @brief Change the current position within the current streaming window
- * @pre GDISP_HARDWARE_STREAM_POS is TRUE and GDISP_HARDWARE_STREAM_WRITE is TRUE
+ * @pre GDISP_HARDWARE_STREAM_POS is GFXON and GDISP_HARDWARE_STREAM_WRITE is GFXON
*
* @param[in] g The driver structure
* @param[in] g->p.x,g->p.y The new position (which will always be within the existing stream window)
@@ -505,7 +505,7 @@ typedef struct GDISPVMT {
#if GDISP_HARDWARE_STREAM_READ || defined(__DOXYGEN__)
/**
* @brief Start a streamed read operation
- * @pre GDISP_HARDWARE_STREAM_READ is TRUE
+ * @pre GDISP_HARDWARE_STREAM_READ is GFXON
*
* @param[in] g The driver structure
* @param[in] g->p.x,g->p.y The window position
@@ -520,7 +520,7 @@ typedef struct GDISPVMT {
/**
* @brief Read a pixel from the current streaming position and then increment that position
* @return The color at the current position
- * @pre GDISP_HARDWARE_STREAM_READ is TRUE
+ * @pre GDISP_HARDWARE_STREAM_READ is GFXON
*
* @param[in] g The driver structure
*
@@ -530,7 +530,7 @@ typedef struct GDISPVMT {
/**
* @brief End the current streaming operation
- * @pre GDISP_HARDWARE_STREAM_READ is TRUE
+ * @pre GDISP_HARDWARE_STREAM_READ is GFXON
*
* @param[in] g The driver structure
*
@@ -542,7 +542,7 @@ typedef struct GDISPVMT {
#if GDISP_HARDWARE_DRAWPIXEL || defined(__DOXYGEN__)
/**
* @brief Draw a pixel
- * @pre GDISP_HARDWARE_DRAWPIXEL is TRUE
+ * @pre GDISP_HARDWARE_DRAWPIXEL is GFXON
*
* @param[in] g The driver structure
* @param[in] g->p.x,g->p.y The pixel position
@@ -556,7 +556,7 @@ typedef struct GDISPVMT {
#if GDISP_HARDWARE_CLEARS || defined(__DOXYGEN__)
/**
* @brief Clear the screen using the defined color
- * @pre GDISP_HARDWARE_CLEARS is TRUE
+ * @pre GDISP_HARDWARE_CLEARS is GFXON
*
* @param[in] g The driver structure
* @param[in] g->p.color The color to set
@@ -569,7 +569,7 @@ typedef struct GDISPVMT {
#if GDISP_HARDWARE_FILLS || defined(__DOXYGEN__)
/**
* @brief Fill an area with a single color
- * @pre GDISP_HARDWARE_FILLS is TRUE
+ * @pre GDISP_HARDWARE_FILLS is GFXON
*
* @param[in] g The driver structure
* @param[in] g->p.x,g->p.y The area position
@@ -584,7 +584,7 @@ typedef struct GDISPVMT {
#if GDISP_HARDWARE_BITFILLS || defined(__DOXYGEN__)
/**
* @brief Fill an area using a bitmap
- * @pre GDISP_HARDWARE_BITFILLS is TRUE
+ * @pre GDISP_HARDWARE_BITFILLS is GFXON
*
* @param[in] g The driver structure
* @param[in] g->p.x,g->p.y The area position
@@ -602,7 +602,7 @@ typedef struct GDISPVMT {
/**
* @brief Read a pixel from the display
* @return The color at the defined position
- * @pre GDISP_HARDWARE_PIXELREAD is TRUE (and the application needs it)
+ * @pre GDISP_HARDWARE_PIXELREAD is GFXON (and the application needs it)
*
* @param[in] g The driver structure
* @param[in] g->p.x,g->p.y The pixel position
@@ -615,7 +615,7 @@ typedef struct GDISPVMT {
#if (GDISP_HARDWARE_SCROLL && GDISP_NEED_SCROLL) || defined(__DOXYGEN__)
/**
* @brief Scroll an area of the screen
- * @pre GDISP_HARDWARE_SCROLL is TRUE (and the application needs it)
+ * @pre GDISP_HARDWARE_SCROLL is GFXON (and the application needs it)
*
* @param[in] g The driver structure
* @param[in] g->p.x,g->p.y The area position
@@ -634,7 +634,7 @@ typedef struct GDISPVMT {
#if (GDISP_HARDWARE_CONTROL && GDISP_NEED_CONTROL) || defined(__DOXYGEN__)
/**
* @brief Control some feature of the hardware
- * @pre GDISP_HARDWARE_CONTROL is TRUE (and the application needs it)
+ * @pre GDISP_HARDWARE_CONTROL is GFXON (and the application needs it)
*
* @param[in] g The driver structure
* @param[in] g->p.x The operation to perform
@@ -649,7 +649,7 @@ typedef struct GDISPVMT {
/**
* @brief Query some feature of the hardware
* @return The information requested (typecast as void *)
- * @pre GDISP_HARDWARE_QUERY is TRUE (and the application needs it)
+ * @pre GDISP_HARDWARE_QUERY is GFXON (and the application needs it)
*
* @param[in] g The driver structure
* @param[in] g->p.x What to query
@@ -662,7 +662,7 @@ typedef struct GDISPVMT {
#if (GDISP_HARDWARE_CLIP && (GDISP_NEED_CLIP || GDISP_NEED_VALIDATION)) || defined(__DOXYGEN__)
/**
* @brief Set the hardware clipping area
- * @pre GDISP_HARDWARE_CLIP is TRUE (and the application needs it)
+ * @pre GDISP_HARDWARE_CLIP is GFXON (and the application needs it)
*
* @param[in] g The driver structure
* @param[in] g->p.x,g->p.y The area position
@@ -706,7 +706,7 @@ typedef struct GDISPVMT {
// Make sure the driver has a valid model
#if !GDISP_HARDWARE_STREAM_WRITE && !GDISP_HARDWARE_DRAWPIXEL
- #error "GDISP Driver: Either GDISP_HARDWARE_STREAM_WRITE or GDISP_HARDWARE_DRAWPIXEL must be TRUE"
+ #error "GDISP Driver: Either GDISP_HARDWARE_STREAM_WRITE or GDISP_HARDWARE_DRAWPIXEL must be GFXON"
#endif
// If we are not using multiple displays then hard-code the VMT name (except for the pixmap driver)
@@ -840,9 +840,9 @@ typedef struct GDISPVMT {
#error "GDISP: Cannot define low level driver color types with more than 32 bits"
#endif
#if LLDCOLOR_TYPE_BITS == LLDCOLOR_BITS
- #define LLDCOLOR_NEEDS_MASK FALSE
+ #define LLDCOLOR_NEEDS_MASK GFXOFF
#else
- #define LLDCOLOR_NEEDS_MASK TRUE
+ #define LLDCOLOR_NEEDS_MASK GFXON
#endif
#define LLDCOLOR_MASK() ((1 << LLDCOLOR_BITS)-1)
@@ -943,9 +943,9 @@ typedef struct GDISPVMT {
#error "GDISP: Cannot define gray-scale low level driver color types with more than 8 bits"
#endif
#if LLDCOLOR_TYPE_BITS == LLDCOLOR_BITS
- #define LLDCOLOR_NEEDS_MASK FALSE
+ #define LLDCOLOR_NEEDS_MASK GFXOFF
#else
- #define LLDCOLOR_NEEDS_MASK TRUE
+ #define LLDCOLOR_NEEDS_MASK GFXON
#endif
#define LLDCOLOR_MASK() ((1 << LLDCOLOR_BITS)-1)
@@ -1005,9 +1005,9 @@ typedef struct GDISPVMT {
*/
#ifndef GDISP_HARDWARE_USE_EXACT_COLOR
#if LLDCOLOR_BITS_R - COLOR_BITS_R >= LLDCOLOR_BITS_R/2 || LLDCOLOR_BITS_G - COLOR_BITS_G >= LLDCOLOR_BITS_G/2 || LLDCOLOR_BITS_B - COLOR_BITS_B >= LLDCOLOR_BITS_B/2
- #define GDISP_HARDWARE_USE_EXACT_COLOR TRUE
+ #define GDISP_HARDWARE_USE_EXACT_COLOR GFXON
#else
- #define GDISP_HARDWARE_USE_EXACT_COLOR FALSE
+ #define GDISP_HARDWARE_USE_EXACT_COLOR GFXOFF
#endif
#endif
diff --git a/src/gdisp/gdisp_image.h b/src/gdisp/gdisp_image.h
index d921e063..4cd348cf 100644
--- a/src/gdisp/gdisp_image.h
+++ b/src/gdisp/gdisp_image.h
@@ -127,7 +127,7 @@ extern "C" {
* @details Determine the image format and get ready to decode the first image frame
* @return GDISP_IMAGE_ERR_OK (0) on success or an error code.
*
- * @pre GFILE_NEED_CHIBIOSFS and GFX_USE_OS_CHIBIOS must be TRUE. This only makes sense on the ChibiOS
+ * @pre GFILE_NEED_CHIBIOSFS and GFX_USE_OS_CHIBIOS must be GFXON. This only makes sense on the ChibiOS
* operating system.
*
* @param[in] img The image structure
@@ -142,7 +142,7 @@ extern "C" {
* @details Determine the image format and get ready to decode the first image frame
* @return GDISP_IMAGE_ERR_OK (0) on success or an error code.
*
- * @pre GFILE_NEED_MEMFS must be TRUE
+ * @pre GFILE_NEED_MEMFS must be GFXON
*
* @param[in] img The image structure
* @param[in] ptr A pointer to the image bytes in memory
diff --git a/src/gdisp/gdisp_options.h b/src/gdisp/gdisp_options.h
index f5f2c18b..8fb409a2 100644
--- a/src/gdisp/gdisp_options.h
+++ b/src/gdisp/gdisp_options.h
@@ -22,175 +22,175 @@
*/
/**
* @brief Should drawing operations be automatically flushed.
- * @details Defaults to FALSE
- * @note If set to FALSE and the controller requires flushing
+ * @details Defaults to GFXOFF
+ * @note If set to GFXOFF and the controller requires flushing
* then the application must manually call @p gdispGFlush().
- * Setting this to TRUE causes GDISP to automatically flush
+ * Setting this to GFXON causes GDISP to automatically flush
* after each drawing operation. Note this may be slow but enables
* an application to avoid having to manually call the flush routine.
- * @note If TRUE and GDISP_NEED_TIMERFLUSH is also TRUE, this takes precedence.
+ * @note If GFXON and GDISP_NEED_TIMERFLUSH is also GFXON, this takes precedence.
* @note Most controllers don't need flushing which is why this is set to
- * FALSE by default.
+ * GFXOFF by default.
*/
#ifndef GDISP_NEED_AUTOFLUSH
- #define GDISP_NEED_AUTOFLUSH FALSE
+ #define GDISP_NEED_AUTOFLUSH GFXOFF
#endif
/**
* @brief Should drawing operations be automatically flushed on a timer.
- * @details Defaults to FALSE, Can be set to FALSE or a timer period in milliseconds.
+ * @details Defaults to GFXOFF, Can be set to GFXOFF or a timer period in milliseconds.
* @note The period should not be set too short or it will consume all your CPU. A
* value between 250 and 500 milliseconds would probably be suitable.
- * @note If TRUE and GDISP_NEED_AUTOFLUSH is also TRUE, this is ineffective.
+ * @note If GFXON and GDISP_NEED_AUTOFLUSH is also GFXON, this is ineffective.
* @note Most controllers don't need flushing which is why this is set to
- * FALSE by default.
+ * GFXOFF by default.
*/
#ifndef GDISP_NEED_TIMERFLUSH
- #define GDISP_NEED_TIMERFLUSH FALSE
+ #define GDISP_NEED_TIMERFLUSH GFXOFF
#endif
/**
* @brief Should all operations be clipped to the screen and colors validated.
- * @details Defaults to TRUE.
- * @note If this is FALSE, any operations that extend beyond the
+ * @details Defaults to GFXON.
+ * @note If this is GFXOFF, any operations that extend beyond the
* edge of the screen will have undefined results. Any
* out-of-range colors will produce undefined results.
- * @note This should always be left as the default (TRUE) unless you
+ * @note This should always be left as the default (GFXON) unless you
* are a maniac for speed and you have thoroughly tested your code
* and it never overwrites the edges of the screen.
- * @note Setting GDISP_NEED_CLIP to TRUE internally uses the same mechanism
- * as this validation. There is no advantage in setting this FALSE if
- * GDISP_NEED_CLIP is TRUE.
+ * @note Setting GDISP_NEED_CLIP to GFXON internally uses the same mechanism
+ * as this validation. There is no advantage in setting this GFXOFF if
+ * GDISP_NEED_CLIP is GFXON.
*/
#ifndef GDISP_NEED_VALIDATION
- #define GDISP_NEED_VALIDATION TRUE
+ #define GDISP_NEED_VALIDATION GFXON
#endif
/**
* @brief Are clipping functions needed.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_CLIP
- #define GDISP_NEED_CLIP TRUE
+ #define GDISP_NEED_CLIP GFXON
#endif
/**
* @brief Streaming functions are needed
- * @details Defaults to FALSE.
+ * @details Defaults to GFXOFF.
*/
#ifndef GDISP_NEED_STREAMING
- #define GDISP_NEED_STREAMING FALSE
+ #define GDISP_NEED_STREAMING GFXOFF
#endif
/**
* @brief Are text functions needed.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note You must also define at least one font.
*/
#ifndef GDISP_NEED_TEXT
- #define GDISP_NEED_TEXT FALSE
+ #define GDISP_NEED_TEXT GFXOFF
#endif
/**
* @brief Are circle functions needed.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note Uses integer algorithms only. It does not use any trig or floating point.
*/
#ifndef GDISP_NEED_CIRCLE
- #define GDISP_NEED_CIRCLE FALSE
+ #define GDISP_NEED_CIRCLE GFXOFF
#endif
/**
* @brief Are dual circle functions needed (one circle inside another).
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note Uses integer algorithms only. It does not use any trig or floating point.
*/
#ifndef GDISP_NEED_DUALCIRCLE
- #define GDISP_NEED_DUALCIRCLE FALSE
+ #define GDISP_NEED_DUALCIRCLE GFXOFF
#endif
/**
* @brief Are ellipse functions needed.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note Uses integer algorithms only. It does not use any trig or floating point.
*/
#ifndef GDISP_NEED_ELLIPSE
- #define GDISP_NEED_ELLIPSE FALSE
+ #define GDISP_NEED_ELLIPSE GFXOFF
#endif
/**
* @brief Are arc sector functions needed.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note Uses integer algorithms only. It does not use any trig or floating point.
*/
#ifndef GDISP_NEED_ARCSECTORS
- #define GDISP_NEED_ARCSECTORS FALSE
+ #define GDISP_NEED_ARCSECTORS GFXOFF
#endif
/**
* @brief Are arc functions needed.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note This can be compiled using fully integer mathematics by
- * defining GFX_USE_GMISC and GMISC_NEED_FIXEDTRIG as TRUE.
+ * defining GFX_USE_GMISC and GMISC_NEED_FIXEDTRIG as GFXON.
* @note This can be compiled to use floating point but no trig functions
- * by defining GFX_USE_GMISC and GMISC_NEED_FASTTRIG as TRUE.
+ * by defining GFX_USE_GMISC and GMISC_NEED_FASTTRIG as GFXON.
* @note If neither of the above are defined it requires the maths library
* to be included in the link to provide floating point and trig support.
* ie include -lm in your compiler flags.
*/
#ifndef GDISP_NEED_ARC
- #define GDISP_NEED_ARC FALSE
+ #define GDISP_NEED_ARC GFXOFF
#endif
/**
* @brief Are convex polygon functions needed.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note Convex polygons are those that have no internal angles. That is;
* you can draw a line from any point on the polygon to any other point
* on the polygon without it going outside the polygon.
*/
#ifndef GDISP_NEED_CONVEX_POLYGON
- #define GDISP_NEED_CONVEX_POLYGON FALSE
+ #define GDISP_NEED_CONVEX_POLYGON GFXOFF
#endif
/**
* @brief Are scrolling functions needed.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note This function must be supported by the low level GDISP driver
* you have included in your project. If it isn't, defining this
* option will cause a compile error.
*/
#ifndef GDISP_NEED_SCROLL
- #define GDISP_NEED_SCROLL FALSE
+ #define GDISP_NEED_SCROLL GFXOFF
#endif
/**
* @brief Is the capability to read pixels back needed.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note This function must be supported by the low level GDISP driver
* you have included in your project. If it isn't, defining this
* option will cause a compile error.
*/
#ifndef GDISP_NEED_PIXELREAD
- #define GDISP_NEED_PIXELREAD FALSE
+ #define GDISP_NEED_PIXELREAD GFXOFF
#endif
/**
* @brief Control some aspect of the hardware operation.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note This allows control of hardware specific features such as
* screen rotation, backlight levels, contrast etc
*/
#ifndef GDISP_NEED_CONTROL
- #define GDISP_NEED_CONTROL FALSE
+ #define GDISP_NEED_CONTROL GFXOFF
#endif
/**
* @brief Query some aspect of the hardware operation.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note This allows query of hardware specific features
*/
#ifndef GDISP_NEED_QUERY
- #define GDISP_NEED_QUERY FALSE
+ #define GDISP_NEED_QUERY GFXOFF
#endif
/**
* @brief Is the image interface required.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GDISP_NEED_IMAGE
- #define GDISP_NEED_IMAGE FALSE
+ #define GDISP_NEED_IMAGE GFXOFF
#endif
/**
* @brief Is the image interface required.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GDISP_NEED_PIXMAP
- #define GDISP_NEED_PIXMAP FALSE
+ #define GDISP_NEED_PIXMAP GFXOFF
#endif
/**
* @}
@@ -200,10 +200,10 @@
*/
/**
* @brief Do the drawing functions need to be thread-safe.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GDISP_NEED_MULTITHREAD
- #define GDISP_NEED_MULTITHREAD FALSE
+ #define GDISP_NEED_MULTITHREAD GFXOFF
#endif
/**
* @}
@@ -214,10 +214,10 @@
/**
* @brief Should the startup logo be displayed
*
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_STARTUP_LOGO
- #define GDISP_NEED_STARTUP_LOGO TRUE
+ #define GDISP_NEED_STARTUP_LOGO GFXON
#endif
/**
* @brief Define the initial background color for all displays in the system.
@@ -270,8 +270,8 @@
* @note The same driver can occur more than once in the list to create an extra instance of that driver.
* @note If defining this you must also define GDISP_PIXELFORMAT for your application to use.
* Choose a value that is most common accross all your drivers for efficiency.
- * @note If using this you may optionally define the GDISP_HARDWARE_xxx values as either TRUE or FALSE.
- * Doing this causes GDISP to assume that all (TRUE) or none (FALSE) of the listed drivers have that
+ * @note If using this you may optionally define the GDISP_HARDWARE_xxx values as either GFXON or GFXOFF.
+ * Doing this causes GDISP to assume that all (GFXON) or none (GFXOFF) of the listed drivers have that
* capability. This can help improve drawing speed and efficiency.
*/
#define GDISP_DRIVER_LIST GDISPVMT_Win32, GDISPVMT_SSD1963
@@ -280,113 +280,113 @@
* @}
*
* @name GDISP Image Options
- * @pre GDISP_NEED_IMAGE must be TRUE
+ * @pre GDISP_NEED_IMAGE must be GFXON
* @{
*/
/**
* @brief Is native image decoding required.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GDISP_NEED_IMAGE_NATIVE
- #define GDISP_NEED_IMAGE_NATIVE FALSE
+ #define GDISP_NEED_IMAGE_NATIVE GFXOFF
#endif
/**
* @brief Is GIF image decoding required.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GDISP_NEED_IMAGE_GIF
- #define GDISP_NEED_IMAGE_GIF FALSE
+ #define GDISP_NEED_IMAGE_GIF GFXOFF
#endif
/**
* @brief Is BMP image decoding required.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GDISP_NEED_IMAGE_BMP
- #define GDISP_NEED_IMAGE_BMP FALSE
+ #define GDISP_NEED_IMAGE_BMP GFXOFF
#endif
/**
* @brief Is JPG image decoding required.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GDISP_NEED_IMAGE_JPG
- #define GDISP_NEED_IMAGE_JPG FALSE
+ #define GDISP_NEED_IMAGE_JPG GFXOFF
#endif
/**
* @brief Is PNG image decoding required.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GDISP_NEED_IMAGE_PNG
- #define GDISP_NEED_IMAGE_PNG FALSE
+ #define GDISP_NEED_IMAGE_PNG GFXOFF
#endif
/**
* @brief Is memory accounting required during image decoding.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GDISP_NEED_IMAGE_ACCOUNTING
- #define GDISP_NEED_IMAGE_ACCOUNTING FALSE
+ #define GDISP_NEED_IMAGE_ACCOUNTING GFXOFF
#endif
/**
* @}
*
* @name GDISP BMP Image Options
- * @pre GDISP_NEED_IMAGE and GDISP_NEED_IMAGE_BMP must be TRUE
+ * @pre GDISP_NEED_IMAGE and GDISP_NEED_IMAGE_BMP must be GFXON
* @{
*/
/**
* @brief Is BMP 1 bit per pixel (monochrome/2 color) image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_BMP_1
- #define GDISP_NEED_IMAGE_BMP_1 TRUE
+ #define GDISP_NEED_IMAGE_BMP_1 GFXON
#endif
/**
* @brief Is BMP 4 bits per pixel (16 color) image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_BMP_4
- #define GDISP_NEED_IMAGE_BMP_4 TRUE
+ #define GDISP_NEED_IMAGE_BMP_4 GFXON
#endif
/**
* @brief Is BMP 4 bits per pixel (16 color) with RLE compression image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_BMP_4_RLE
- #define GDISP_NEED_IMAGE_BMP_4_RLE TRUE
+ #define GDISP_NEED_IMAGE_BMP_4_RLE GFXON
#endif
/**
* @brief Is BMP 8 bits per pixel (256 color) image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_BMP_8
- #define GDISP_NEED_IMAGE_BMP_8 TRUE
+ #define GDISP_NEED_IMAGE_BMP_8 GFXON
#endif
/**
* @brief Is BMP 8 bits per pixel (256 color) with RLE compression image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_BMP_8_RLE
- #define GDISP_NEED_IMAGE_BMP_8_RLE TRUE
+ #define GDISP_NEED_IMAGE_BMP_8_RLE GFXON
#endif
/**
* @brief Is BMP 16 bits per pixel (65536 color) image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_BMP_16
- #define GDISP_NEED_IMAGE_BMP_16 TRUE
+ #define GDISP_NEED_IMAGE_BMP_16 GFXON
#endif
/**
* @brief Is BMP 24 bits per pixel (true-color) image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_BMP_24
- #define GDISP_NEED_IMAGE_BMP_24 TRUE
+ #define GDISP_NEED_IMAGE_BMP_24 GFXON
#endif
/**
* @brief Is BMP 32 bits per pixel (true-color) image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_BMP_32
- #define GDISP_NEED_IMAGE_BMP_32 TRUE
+ #define GDISP_NEED_IMAGE_BMP_32 GFXON
#endif
/**
* @brief The BMP blit buffer size.
@@ -401,7 +401,7 @@
* @}
*
* @name GDISP GIF Image Options
- * @pre GDISP_NEED_IMAGE and GDISP_NEED_IMAGE_GIF must be TRUE
+ * @pre GDISP_NEED_IMAGE and GDISP_NEED_IMAGE_GIF must be GFXON
* @{
*/
/**
@@ -416,37 +416,37 @@
* @}
*
* @name GDISP PNG Image Options
- * @pre GDISP_NEED_IMAGE and GDISP_NEED_IMAGE_PNG must be TRUE
+ * @pre GDISP_NEED_IMAGE and GDISP_NEED_IMAGE_PNG must be GFXON
* @{
*/
/**
* @brief Is PNG Interlaced image decoding required.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
* @note Currently not supported due to the complex decoding and display requirements
*/
#ifndef GDISP_NEED_IMAGE_PNG_INTERLACED
- #define GDISP_NEED_IMAGE_PNG_INTERLACED FALSE
+ #define GDISP_NEED_IMAGE_PNG_INTERLACED GFXOFF
#endif
/**
* @brief Is PNG image transparency processed.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_PNG_TRANSPARENCY
- #define GDISP_NEED_IMAGE_PNG_TRANSPARENCY TRUE
+ #define GDISP_NEED_IMAGE_PNG_TRANSPARENCY GFXON
#endif
/**
* @brief Is PNG background data processed.
- * @details Defaults to TRUE
- * @note If the background is specified in the image file and this define is TRUE,
+ * @details Defaults to GFXON
+ * @note If the background is specified in the image file and this define is GFXON,
* that background color is used for transparency and alpha blending.
*/
#ifndef GDISP_NEED_IMAGE_PNG_BACKGROUND
- #define GDISP_NEED_IMAGE_PNG_BACKGROUND TRUE
+ #define GDISP_NEED_IMAGE_PNG_BACKGROUND GFXON
#endif
/**
* @brief What is the cliff between non-blended alpha pixels being displayed or not.
* @details Range of 0 to 255
- * @note If GDISP_NEED_IMAGE_PNG_BACKGROUND is TRUE and the PNG file contains a
+ * @note If GDISP_NEED_IMAGE_PNG_BACKGROUND is GFXON and the PNG file contains a
* background color then the pixel will be blended with the background color
* according to the alpha.
* If not then no blending occurs. The pixel will either be set or not.
@@ -458,80 +458,80 @@
#endif
/**
* @brief Is 1, 2 and 4 bit PNG palettized image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_PNG_PALETTE_124
- #define GDISP_NEED_IMAGE_PNG_PALETTE_124 TRUE
+ #define GDISP_NEED_IMAGE_PNG_PALETTE_124 GFXON
#endif
/**
* @brief Is 8 bit PNG palettized image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_PNG_PALETTE_8
- #define GDISP_NEED_IMAGE_PNG_PALETTE_8 TRUE
+ #define GDISP_NEED_IMAGE_PNG_PALETTE_8 GFXON
#endif
/**
* @brief Is 1,2 and 4 bit PNG grayscale image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_PNG_GRAYSCALE_124
- #define GDISP_NEED_IMAGE_PNG_GRAYSCALE_124 TRUE
+ #define GDISP_NEED_IMAGE_PNG_GRAYSCALE_124 GFXON
#endif
/**
* @brief Is 8 bit PNG grayscale image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_PNG_GRAYSCALE_8
- #define GDISP_NEED_IMAGE_PNG_GRAYSCALE_8 TRUE
+ #define GDISP_NEED_IMAGE_PNG_GRAYSCALE_8 GFXON
#endif
/**
* @brief Is 16 bit PNG grayscale image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_PNG_GRAYSCALE_16
- #define GDISP_NEED_IMAGE_PNG_GRAYSCALE_16 TRUE
+ #define GDISP_NEED_IMAGE_PNG_GRAYSCALE_16 GFXON
#endif
/**
* @brief Is 8 bit PNG grayscale with 8 bit alpha image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_PNG_GRAYALPHA_8
- #define GDISP_NEED_IMAGE_PNG_GRAYALPHA_8 TRUE
+ #define GDISP_NEED_IMAGE_PNG_GRAYALPHA_8 GFXON
#endif
/**
* @brief Is 16 bit PNG grayscale with 16 bit alpha image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_PNG_GRAYALPHA_16
- #define GDISP_NEED_IMAGE_PNG_GRAYALPHA_16 TRUE
+ #define GDISP_NEED_IMAGE_PNG_GRAYALPHA_16 GFXON
#endif
/**
* @brief Is 8/8/8 bit PNG RGB image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_PNG_RGB_8
- #define GDISP_NEED_IMAGE_PNG_RGB_8 TRUE
+ #define GDISP_NEED_IMAGE_PNG_RGB_8 GFXON
#endif
/**
* @brief Is 16/16/16 bit PNG RGB image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_PNG_RGB_16
- #define GDISP_NEED_IMAGE_PNG_RGB_16 TRUE
+ #define GDISP_NEED_IMAGE_PNG_RGB_16 GFXON
#endif
/**
* @brief Is 8/8/8 bit PNG RGB with 8 bit alpha image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_PNG_RGBALPHA_8
- #define GDISP_NEED_IMAGE_PNG_RGBALPHA_8 TRUE
+ #define GDISP_NEED_IMAGE_PNG_RGBALPHA_8 GFXON
#endif
/**
* @brief Is 16/16/16 bit PNG RGB with 16 bit alpha image decoding required.
- * @details Defaults to TRUE
+ * @details Defaults to GFXON
*/
#ifndef GDISP_NEED_IMAGE_PNG_RGBALPHA_16
- #define GDISP_NEED_IMAGE_PNG_RGBALPHA_16 TRUE
+ #define GDISP_NEED_IMAGE_PNG_RGBALPHA_16 GFXON
#endif
/**
* @brief The PNG blit buffer size in pixels.
@@ -569,10 +569,10 @@
/**
* @brief Enable advanced word-wrapping.
* @details Only has an effect with @p gdispGDrawStringBox() and @p gdispGFillStringBox()
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GDISP_NEED_TEXT_WORDWRAP
- #define GDISP_NEED_TEXT_WORDWRAP FALSE
+ #define GDISP_NEED_TEXT_WORDWRAP GFXOFF
#endif
/**
* @brief Adding pixels to the left and right side of the box to pad text.
@@ -594,24 +594,24 @@
#endif
/**
* @brief Enable UTF-8 support for text rendering.
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GDISP_NEED_UTF8
- #define GDISP_NEED_UTF8 FALSE
+ #define GDISP_NEED_UTF8 GFXOFF
#endif
/**
* @brief Enable kerning for font rendering (improves character placement).
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GDISP_NEED_TEXT_KERNING
- #define GDISP_NEED_TEXT_KERNING FALSE
+ #define GDISP_NEED_TEXT_KERNING GFXOFF
#endif
/**
* @brief Enable antialiased font support
- * @details Defaults to FALSE
+ * @details Defaults to GFXOFF
*/
#ifndef GDISP_NEED_ANTIALIAS
- #define GDISP_NEED_ANTIALIAS FALSE
+ #define GDISP_NEED_ANTIALIAS GFXOFF
#endif
/**
* @}
@@ -620,7 +620,7 @@
* @{
*/
#ifndef GDISP_NEED_PIXMAP_IMAGE
- #define GDISP_NEED_PIXMAP_IMAGE FALSE
+ #define GDISP_NEED_PIXMAP_IMAGE GFXOFF
#endif
/**
* @}
diff --git a/src/gdisp/gdisp_pixmap.c b/src/gdisp/gdisp_pixmap.c
index c22ffcf0..45dee66b 100644
--- a/src/gdisp/gdisp_pixmap.c
+++ b/src/gdisp/gdisp_pixmap.c
@@ -25,11 +25,11 @@
#undef GDISP_HARDWARE_CONTROL
#undef GDISP_HARDWARE_QUERY
#undef GDISP_HARDWARE_CLIP
-#define GDISP_HARDWARE_DEINIT TRUE
-#define GDISP_HARDWARE_DRAWPIXEL TRUE
-#define GDISP_HARDWARE_PIXELREAD TRUE
-#define GDISP_HARDWARE_CONTROL TRUE
-#define IN_PIXMAP_DRIVER TRUE
+#define GDISP_HARDWARE_DEINIT GFXON
+#define GDISP_HARDWARE_DRAWPIXEL GFXON
+#define GDISP_HARDWARE_PIXELREAD GFXON
+#define GDISP_HARDWARE_CONTROL GFXON
+#define IN_PIXMAP_DRIVER GFXON
#define GDISP_DRIVER_VMT GDISPVMT_pixmap
#define GDISP_DRIVER_VMT_FLAGS (GDISP_VFLG_DYNAMICONLY|GDISP_VFLG_PIXMAP)
diff --git a/src/gdisp/gdisp_pixmap.h b/src/gdisp/gdisp_pixmap.h
index a8024772..ebf7e1db 100644
--- a/src/gdisp/gdisp_pixmap.h
+++ b/src/gdisp/gdisp_pixmap.h
@@ -15,7 +15,7 @@
*
* @note A Pixmap is an off-screen virtual display that can be drawn to just like any other
* display. It can then be copied to a real display using the standard gdispGBlitArea() call.
- * @pre GDISP_NEED_PIXMAP must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_PIXMAP must be GFXON in your gfxconf.h
* @{
*/
@@ -69,7 +69,7 @@ extern "C" {
/**
* @brief Get a pointer to a native format gdispImage.
* @return A pointer to a NATIVE format gdispImage in memory or NULL if this display is not a pixmap.
- * @pre GDISP_NEED_PIXAMP_IMAGE must be TRUE in your gfxconf.h
+ * @pre GDISP_NEED_PIXAMP_IMAGE must be GFXON in your gfxconf.h
*
* @param[in] g The pixmap virtual display
*
diff --git a/src/gdisp/gdisp_rules.h b/src/gdisp/gdisp_rules.h
index d9fb86bb..f6557d8f 100644
--- a/src/gdisp/gdisp_rules.h
+++ b/src/gdisp/gdisp_rules.h
@@ -26,7 +26,7 @@
#endif
#endif
#undef GFX_USE_GDRIVER
- #define GFX_USE_GDRIVER TRUE
+ #define GFX_USE_GDRIVER GFXON
#endif
#if defined(GDISP_DRIVER_LIST)
#if GDISP_TOTAL_DISPLAYS != 1
@@ -45,11 +45,11 @@
#endif
#endif
#undef GDISP_NEED_TIMERFLUSH
- #define GDISP_NEED_TIMERFLUSH FALSE
+ #define GDISP_NEED_TIMERFLUSH GFXOFF
#endif
#if GDISP_NEED_TIMERFLUSH
#if GDISP_NEED_TIMERFLUSH < 50 || GDISP_NEED_TIMERFLUSH > 1200
- #error "GDISP: GDISP_NEED_TIMERFLUSH has been set to an invalid value (FALSE, 50-1200)."
+ #error "GDISP: GDISP_NEED_TIMERFLUSH has been set to an invalid value (GFXOFF, 50-1200)."
#endif
#if !GFX_USE_GTIMER
#if GFX_DISPLAY_RULE_WARNINGS
@@ -60,9 +60,9 @@
#endif
#endif
#undef GFX_USE_GTIMER
- #define GFX_USE_GTIMER TRUE
+ #define GFX_USE_GTIMER GFXON
#undef GDISP_NEED_MULTITHREAD
- #define GDISP_NEED_MULTITHREAD TRUE
+ #define GDISP_NEED_MULTITHREAD GFXON
#endif
#endif
#if GDISP_NEED_ANTIALIAS && !GDISP_NEED_PIXELREAD
@@ -75,7 +75,7 @@
#endif
#endif
#undef GDISP_NEED_PIXELREAD
- #define GDISP_NEED_PIXELREAD TRUE
+ #define GDISP_NEED_PIXELREAD GFXON
#else
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
@@ -97,19 +97,19 @@
#endif
#endif
#undef GDISP_INCLUDE_FONT_UI2
- #define GDISP_INCLUDE_FONT_UI2 TRUE
+ #define GDISP_INCLUDE_FONT_UI2 GFXON
#endif
#if GDISP_NEED_IMAGE
#if !GFX_USE_GFILE
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
#warning "GDISP: GFX_USE_GFILE is required when GDISP_NEED_IMAGE is TRUE. It has been turned on for you."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO
- COMPILER_WARNING("GDISP: GFX_USE_GFILE is required when GDISP_NEED_IMAGE is TRUE. It has been turned on for you.")
+ COMPILER_WARNING("GDISP: GFX_USE_GFILE is required when GDISP_NEED_IMAGE is GFXON. It has been turned on for you.")
#endif
#endif
#undef GFX_USE_GFILE
- #define GFX_USE_GFILE TRUE
+ #define GFX_USE_GFILE GFXON
#endif
#endif
#endif
@@ -97,19 +97,19 @@
#if GFX_DISPLAY_RULE_WARNINGS
#if GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_DIRECT
- #warning "GDISP: GFX_USE_GFILE is required when GDISP_NEED_IMAGE is TRUE. It has been turned on for you."
+ #warning "GDISP: GFX_USE_GFILE is required when GDISP_NEED_IMAGE is GFXON. It has been turned on for you."
#elif GFX_COMPILER_WARNING_TYPE == GFX_COMPILER_WARNING_MACRO